@@ -53,15 +53,9 @@ class S3(tion):
         _LOGGER.debug("Response is %s", bytes(response).hex())
         return response
 
-    def pair(self):
-        _LOGGER.setLevel("DEBUG")
-        _LOGGER.debug("Pairing")
-        _LOGGER.debug("Connecting")
-        self._do_action(self._connect)
+    def _pair(self):
         _LOGGER.debug("Sending pair command")
         self._send_request(self.pair_command)
-        _LOGGER.debug("Disconnecting")
-        self._disconnect()
         _LOGGER.debug("Done!")
 
     def create_command(self, command: int) -> bytearray:
@@ -101,7 +95,7 @@ class S3(tion):
         _LOGGER.debug("Data is %s", bytes(response).hex())
         try:
             self._fan_speed = int(list("{:02x}".format(response[2]))[1])
-            self._mode = response[2]
+            self._mode = int(list("{:02x}".format(response[2]))[0])
             self._heater = response[4] & 1
             self._state = response[4] >> 1 & 1
             self._target_temp = response[3]
